Hidex 300 SL processor
======================

This tutorial aims to help users understand how to process the measurements of a radionuclide obtained by a
Hidex 300 SL automatic liquid scintillator counter TDCR system using MetPyRad.
The tool that MetPyRad provides to do this is the ``Hidex300`` class.

This tutorial provides the users with a basic understanding of the ``Hidex300`` class.
It will guide you through the initial setup, processing the readings data, visualizing the measurements, and exporting the measurement data.

.. toctree::
    :maxdepth: 2
    :caption: Contents

    hidex300_1
    hidex300_2
    hidex300_3
    hidex300_4
